dhcpkit.ipv6.option_handlers.rapid_commit module
================================================

.. automodule:: dhcpkit.ipv6.option_handlers.rapid_commit
    :members:
    :undoc-members:
    :show-inheritance:
